@@ -1,5 +1,8 @@
 {-# LANGUAGE CPP, NoImplicitPrelude #-}
 {-# LANGUAGE RankNTypes #-}
+#if __GLASGOW_HASKELL__ >= 702
+{-# LANGUAGE Trustworthy #-}
+#endif
 module Data.Type.Coercion.Compat (
 #if MIN_VERSION_base(4,7,0)
   module Base
